@@ -7,7 +7,7 @@ from .middlewares.exception_handler import ExceptionHandlingMiddleware
 from zylo_docs.services.openapi_service import OpenApiService 
 from zylo_docs.logging import NoZyloDocsLogFilter
 # 로깅 삭제하는 코드 개발 모드에서는 주석 처리
-# NoZyloDocsLogFilter().setup_logging()
+NoZyloDocsLogFilter().setup_logging()
 HOST = os.getenv("SERVER_HOST", "localhost")
 PORT = os.getenv("SERVER_PORT", "8000")
 
@@ -16,7 +16,10 @@ def set_initial_openapi_spec(app: FastAPI):
     app.state.openapi_service.set_current_spec(openapi_json)
     print(f"http://{HOST}:{PORT}/zylo-docs")
 
-def add_zylo_docs(app: FastAPI):
+def zylo_docs(app: FastAPI):
+    @app.on_event("startup")
+    async def on_startup():
+        set_initial_openapi_spec(app)
     if not hasattr(app.state, 'openapi_service'):
         app.state.openapi_service = OpenApiService()
         
@@ -29,6 +32,3 @@ def add_zylo_docs(app: FastAPI):
     @app.get("/zylo-docs{full_path:path}", include_in_schema=False)
     async def serve_react_app():
         return FileResponse(os.path.join(os.path.dirname(__file__), "static", "index.html"))
-
-    set_initial_openapi_spec(app)
-#dd
